@@ -20,11 +20,12 @@ except:
 	from halo import Halo
 
 from kxy.api import APIClient, upload_data
+from kxy.misc import LongerThanExpectedException
 
 # Cache old job ids to avoid being charged twice for the same job.
 EXPLANATION_JOB_IDS = {}
 
-def model_explanation(data_df, prediction_column, problem_type, snr='auto'):
+def model_explanation(data_df, prediction_column, problem_type, snr='auto', file_name=None):
 	"""
 	.. _model-explanation:
 	Analyzes the variables that a model relies on the most in a brute-force fashion.
@@ -44,7 +45,8 @@ def model_explanation(data_df, prediction_column, problem_type, snr='auto'):
 		The name of the column containing true labels.
 	problem_type : None | 'classification' | 'regression'
 		The type of supervised learning problem. When None, it is inferred from the column type and the number of distinct values.
-
+	file_name : None | str
+		A unique identifier characterizing data_df in the form of a file name. Do not set this unless you know why.
 
 
 	Returns
@@ -72,11 +74,11 @@ def model_explanation(data_df, prediction_column, problem_type, snr='auto'):
 	k = 0
 	kp = 0
 	max_k = 100
+
+	file_name = upload_data(data_df, file_name=file_name)
 	spinner = Halo(text='Waiting for results from the backend.', spinner='dots')
 	spinner.start()
 
-
-	file_name = upload_data(data_df)
 	if file_name:
 		job_id = EXPLANATION_JOB_IDS.get((file_name, prediction_column, problem_type), None)
 		if job_id:
@@ -118,12 +120,12 @@ def model_explanation(data_df, prediction_column, problem_type, snr='auto'):
 						try:
 							response = api_response.json()
 							if 'eta' in response:
-								progress_text = '%s% Completed.' % response['progress_pct'] if 'progress_pct' in response else ''
+								progress_text = '%s%% Completed.' % response['progress_pct'] if 'progress_pct' in response else ''
 								spinner.text = 'Waiting for results from the backend. ETA: %s. %s' % (response['eta'], progress_text)
 						except:
 							pass
 
-					if 'job_id' not in response:
+					if ('job_id' not in response) or ('selection_order' in response):
 						duration = int(time()-initial_time)
 						duration = str(duration) + 's' if duration < 60 else str(duration//60) + 'min'
 
@@ -173,6 +175,8 @@ def model_explanation(data_df, prediction_column, problem_type, snr='auto'):
 			except:
 				logging.error('\nModel explanation failed. Last HTTP code: %s, Content: %s' % (api_response.status_code, api_response.content))
 
+	raise LongerThanExpectedException('The backend is taking longer than expected, but rest reassured your task is still running. Please try again later to retrieve your results.')
+
 	return None
 
 
